@@ -19,8 +19,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     cc.configure_mesh()
         .x_labels(20)
         .y_labels(10)
-        .disable_x_mesh()
-        .disable_y_mesh()
+        .disable_mesh()
         .x_label_formatter(&|v| format!("{:.1}", v))
         .y_label_formatter(&|v| format!("{:.1}", v))
         .draw()?;
@@ -70,7 +69,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 
     for (drawing_area, idx) in drawing_areas.iter().zip(1..) {
         let mut cc = ChartBuilder::on(&drawing_area)
-            .x_label_area_size(50)
+            .x_label_area_size(30)
             .y_label_area_size(30)
             .margin_right(20)
             .caption(format!("y = x^{}", 1 + 2 * idx), ("Arial", 40).into_font())
