@@ -14,7 +14,6 @@
 <a href="https://travis-ci.org/38/plotters">
     <img style="display: inline! important" src="https://travis-ci.org/38/plotters.svg?branch=master"></img>
 </a>
-
 <a href="https://codecov.io/gh/38/plotters">
   <img src="https://codecov.io/gh/38/plotters/branch/master/graph/badge.svg" />
 </a>
@@ -22,8 +21,10 @@
 Plotters is drawing library designed for rendering figures, plots, and charts, in pure rust. Plotters supports various types of backends,
 including bitmap, vector graph, piston window, GTK/Cairo and WebAssembly.
 
+- A new Plotters Developer's Guide is working in progress. The preview version is available at [here](https://plotters-rs.github.io/book).
 - To try Plotters with inverative Jupyter notebook, or view [here](https://plotters-rs.github.io/plotters-doc-data/evcxr-jupyter-integration.html) for the static HTML version.
 - To view the WASM example, go to this [link](https://plumberserver.com/plotters-wasm-demo/index.html)
+- Currently we have all the internal code ready for console plotting, but a console based backend is still not ready. See [this example](https://github.com/38/plotters/blob/master/examples/console.rs) for how to plotting on Console with a customized backend.
 
 ## Gallery
 
@@ -66,6 +67,15 @@ including bitmap, vector graph, piston window, GTK/Cairo and WebAssembly.
     </div>
 </div>
 
+<div class="galleryItem">
+    <a href="https://plotters-rs.github.io/plotters-doc-data/console-2.png">
+        <img src="https://plotters-rs.github.io/plotters-doc-data/console-2.png" class="galleryItem"></img>
+    </a>
+    <div class="galleryText">
+        Plotting the Console
+    </div>
+</div>
+
 <div class="galleryItem">
     <a href="https://plotters-rs.github.io/plotters-doc-data/mandelbrot.png">
         <img src="https://plotters-rs.github.io/plotters-doc-data/mandelbrot.png" class="galleryItem"></img>
@@ -188,7 +198,7 @@ including bitmap, vector graph, piston window, GTK/Cairo and WebAssembly.
 
 
 <div class="galleryItem">
-    <a href="https://plotters-rs.github.io/plotters-doc-data/animation.png">
+    <a href="https://plotters-rs.github.io/plotters-doc-data/animation.gif">
         <img src="https://plotters-rs.github.io/plotters-doc-data/animation.gif" class="galleryItem"></img>
     </a>
     <div class="galleryText">
@@ -198,6 +208,27 @@ including bitmap, vector graph, piston window, GTK/Cairo and WebAssembly.
 </div>
 
 
+<div class="galleryItem">
+    <a href="https://plotters-rs.github.io/plotters-doc-data/console.png">
+        <img src="https://plotters-rs.github.io/plotters-doc-data/console.png" class="galleryItem"></img>
+    </a>
+    <div class="galleryText">
+        Drawing on a Console
+        <a href="https://github.com/38/plotters/blob/master/examples/console.rs">[code]</a>
+    </div>
+</div>
+
+<div class="galleryItem">
+    <a href="https://plotters-rs.github.io/plotters-doc-data/blit-bitmap.png">
+        <img src="https://plotters-rs.github.io/plotters-doc-data/blit-bitmap.png" class="galleryItem"></img>
+    </a>
+    <div class="galleryText">
+        Drawing bitmap on chart
+        <a href="https://github.com/38/plotters/blob/master/examples/blit-bitmap.rs">[code]</a>
+    </div>
+</div>
+
+
 ## Table of Contents
   * [Gallery](#gallery)
   * [Quick Start](#quick-start)
@@ -223,7 +254,7 @@ including bitmap, vector graph, piston window, GTK/Cairo and WebAssembly.
 To use Plotters, you can simply add Plotters into your `Cargo.toml`
 ```toml
 [dependencies]
-plotters = "^0.2.8"
+plotters = "^0.2.9"
 ```
 
 And the following code draws a quadratic function. `src/main.rs`,
@@ -652,6 +683,9 @@ pub mod prelude {
         MultiLineText, Path, Pixel, Polygon, Rectangle, Text, TriangleMarker,
     };
 
+    #[cfg(all(not(target_arch = "wasm32"), feature = "image"))]
+    pub use crate::element::BitMapElement;
+
     #[allow(type_alias_bounds)]
     /// The type used to returns a drawing operation that can be failed
     /// - `T`: The return type
